symmat: A Symbolic Toolbox for Matrix Calculation
=======================

## Website

https://symmat.github.io


## API

`simplify(expression: str)->str`: Simplify an matrix expression


Disclaimer: It is in alpha version. We are on the way to support more matrix simplification rules.
